package tls

import (
	utls "github.com/refraction-networking/utls"
)

func GetFingerprint(name string) (fingerprint *utls.ClientHelloID) {
	if name == "" {
		return &utls.HelloChrome_Auto
	}
	if fingerprint = Fingerprints[name]; fingerprint != nil {
		return
	}
	return
}

var Fingerprints = map[string]*utls.ClientHelloID{
	"golang": &utls.HelloGolang,
	"custom": &utls.HelloCustom,

	"randomized":       &utls.HelloRandomized,
	"randomizedALPN":   &utls.HelloRandomizedALPN,
	"randomizedNoALPN": &utls.HelloRandomizedNoALPN,

	"firefox":     &utls.HelloFirefox_Auto,
	"firefox_55":  &utls.HelloFirefox_55,
	"firefox_56":  &utls.HelloFirefox_56,
	"firefox_63":  &utls.HelloFirefox_63,
	"firefox_65":  &utls.HelloFirefox_65,
	"firefox_99":  &utls.HelloFirefox_99,
	"firefox_102": &utls.HelloFirefox_102,
	"firefox_105": &utls.HelloFirefox_105,
	"firefox_120": &utls.HelloFirefox_120,

	"chrome":         &utls.HelloChrome_Auto,
	"chrome_58":      &utls.HelloChrome_58,
	"chrome_62":      &utls.HelloChrome_62,
	"chrome_70":      &utls.HelloChrome_70,
	"chrome_72":      &utls.HelloChrome_72,
	"chrome_83":      &utls.HelloChrome_83,
	"chrome_87":      &utls.HelloChrome_87,
	"chrome_96":      &utls.HelloChrome_96,
	"chrome_100":     &utls.HelloChrome_100,
	"chrome_102":     &utls.HelloChrome_102,
	"chrome_106":     &utls.HelloChrome_106_Shuffle,
	"chrome_100_psk": &utls.HelloChrome_100_PSK,
	"chrome_112":     &utls.HelloChrome_112_PSK_Shuf,
	"chrome_114":     &utls.HelloChrome_114_Padding_PSK_Shuf,
	"chrome_115":     &utls.HelloChrome_115_PQ,
	"chrome_115_psk": &utls.HelloChrome_115_PQ_PSK,
	"chrome_120":     &utls.HelloChrome_120,
	"chrome_120_pq":  &utls.HelloChrome_120_PQ,
	"chrome_131":     &utls.HelloChrome_131,

	"ios":    &utls.HelloIOS_Auto,
	"ios_11": &utls.HelloIOS_11_1,
	"ios_12": &utls.HelloIOS_12_1,
	"ios_13": &utls.HelloIOS_13,
	"ios_14": &utls.HelloIOS_14,

	"android": &utls.HelloAndroid_11_OkHttp,

	"edge":     &utls.HelloEdge_Auto,
	"edge_85":  &utls.HelloEdge_85,
	"edge_106": &utls.HelloEdge_106,

	"safari":    &utls.HelloSafari_Auto,
	"safari_16": &utls.HelloSafari_16_0,

	"360":     &utls.Hello360_Auto,
	"360_7_5": &utls.Hello360_7_5,
	"360_11":  &utls.Hello360_11_0,

	"qq":    &utls.HelloQQ_Auto,
	"qq_11": &utls.HelloQQ_11_1,
}
